{% load i18n static %}

<div class="flex flex-row">
    <div class="border flex items-center overflow-hidden rounded-md shadow-sm text-sm max-w-2xl w-full dark:border-gray-700">
        {% if widget.is_initial and not widget.required %}
            <div class="bg-gray-50 border-r flex flex-none items-center self-stretch px-3 dark:bg-gray-900">
                <label for="{{ widget.checkbox_id }}" class="flex items-center">
                    <input type="checkbox" class="form-check-input" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" />

                    <span class="ml-2 text-gray-500">
                        {{ widget.clear_checkbox_label }}
                    </span>
                </label>
            </div>
        {% endif %}

        <input type="text" value="{% if widget.value %}{{ widget.value.url }}{% else %}{% trans 'Choose file to upload' %}{% endif %}" disabled class="bg-white flex-grow font-medium px-3 py-2 text-ellipsis dark:bg-gray-900 {% if widget.value %}text-gray-500 dark:text-gray-400{% else %}text-gray-300 dark:text-gray-400{% endif %}">

        <div class="flex flex-none items-center leading-none self-stretch">
            <input id="{{ widget.name }}" type="{{ widget.type }}" name="{{ widget.name }}" class="hidden" {% include "django/forms/widgets/attrs.html" %} />

            <label for="{{ widget.name }}" class="cursor-pointer text-gray-400 px-3 dark:text-gray-400">
                <span class="material-symbols-outlined">file_upload</span>
            </label>
        </div>
    </div>

    {% if widget.attrs.accept == 'image/*' and widget.is_initial %}
        <div class="bg-gray-50 border h-9 ml-3 overflow-hidden relative rounded-md shadow-sm w-9 dark:bg-gray-900 dark:border-gray-700 dark:text-gray-500">
            <div class="absolute block flex font-medium h-full items-center left-0 justify-center text-gray-400 top-0 w-full z-10 dark:text-gray-500">
                ?
            </div>

            <a href="{{ widget.value.url }}" target="_blank" class="bg-center bg-cover bg-no-repeat block h-9 relative w-9 z-20" style="background-image: url('{{ widget.value.url }}')">
            </a>
        </div>
    {% endif %}
</div>
