{% load i18n %}

<div class="flex items-center ">
    <div class="block bg-red-500 mr-3 rounded-full h-1 w-1 {% if value == '' or value == None %} bg-gray-500{% elif value %} bg-green-500{% else %} bg-red-500{% endif %}"></div>

    <span>
        {% if value == '' or value == None %}
            {% trans 'Unknown' %}
        {% elif value %}
            {% trans 'True' %}
        {% else %}
            {% trans 'False' %}
        {% endif %}
    </span>
</div>
